@@ -38,11 +38,7 @@
 #include "champlain-version.h"
 #include "champlain-tile.h"
 
-#ifdef HAVE_LIBSOUP_GNOME
-#include <libsoup/soup-gnome.h>
-#else
 #include <libsoup/soup.h>
-#endif
 
 G_DEFINE_TYPE (ChamplainNetworkBboxTileSource, champlain_network_bbox_tile_source, CHAMPLAIN_TYPE_TILE_SOURCE)
 
@@ -201,7 +197,7 @@ champlain_network_bbox_tile_source_class_init (ChamplainNetworkBboxTileSourceCla
   /**
    * ChamplainNetworkBboxTileSource:proxy-uri:
    *
-   * The proxy URI to use to access network
+   * Used to override the default proxy for accessing the network.
    *
    * Since: 0.8
    */
@@ -242,12 +238,11 @@ champlain_network_bbox_tile_source_init (ChamplainNetworkBboxTileSource *self)
   priv->api_uri = g_strdup ("http://www.informationfreeway.org/api/0.6");
   /* informationfreeway.org is a load-balancer for different api servers */
   priv->proxy_uri = g_strdup ("");
-  priv->soup_session = soup_session_async_new_with_options (
+  priv->soup_session = soup_session_new_with_options (
         "proxy-uri", soup_uri_new (priv->proxy_uri),
-#ifdef HAVE_LIBSOUP_GNOME
+        "ssl-strict", FALSE,
         SOUP_SESSION_ADD_FEATURE_BY_TYPE, 
-        SOUP_TYPE_PROXY_RESOLVER_GNOME,
-#endif
+        SOUP_TYPE_PROXY_RESOLVER_DEFAULT,
         NULL);
   g_object_set (G_OBJECT (priv->soup_session),
       "user-agent", 
